@@ -33,28 +33,65 @@
  *  ޤơʤݾڤԤʤޤܥեȥѤˤľ
  *  ŪޤϴŪʤ»˴ؤƤ⡤Ǥʤ
  * 
- *  @(#) $Id: rx63n.h,v 1.3 2015/06/28 16:29:50 ssuzuki Exp $
+ *  @(#) $Id: rx63n.h,v 1.4 2015/07/20 14:55:45 ssuzuki Exp $
  */
 
 #ifndef	_RX63N_H_
 #define	_RX63N_H_
 
-#define	RX63N_MSTPCRA		(0x00080010)
-#define	RX63N_MSTPCRB		(0x00080014)
-#define	RX63N_MSTPCRC		(0x00080018)
-#define	RX63N_MSTPCRD		(0x0008001c)
-
+/*
+ * åȯϩ
+ */
 #define	RX63N_SCKCR		(0x00080020)
 #define	RX63N_SCKCR2		(0x00080024)
 #define	RX63N_SCKCR3		(0x00080026)
 #define	RX63N_PLLCR		(0x00080028)
 #define	RX63N_PLLCR2		(0x0008002a)
+#define	RX63N_BCKCR		(0x00080030)
 #define	RX63N_MOSCCR		(0x00080032)
-#define	RX63N_MOSCWTCR		(0x000800a2)
-#define	RX63N_PLLWTCR		(0x000800a6)
+#define	RX63N_SOSCCR		(0x00080033)
+#define	RX63N_LOCOCR		(0x00080034)
+#define	RX63N_ILOCOCR		(0x00080035)
+#define	RX63N_HOCOCR		(0x00080036)
+#define	RX63N_OSTDCR		(0x00080040)
+#define	RX63N_OSTDSR		(0x00080041)
+#define	RX63N_MOFCR		(0x0008c293)
+#define	RX63N_HOCOPCR		(0x0008c294)
 
+/*
+ * 㸺ǽ
+ */
+#define	RX63N_MSTPCRA		(0x00080010)
+#define	RX63N_MSTPCRB		(0x00080014)
+#define	RX63N_MSTPCRC		(0x00080018)
+#define	RX63N_MSTPCRD		(0x0008001c)
+#define	RX63N_OPCCR		(0x000800a0)
+#define	RX63N_RSTCKCR		(0x000800a1)
+#define	RX63N_MOSCWTCR		(0x000800a2)
+#define	RX63N_SOSCWTCR		(0x000800a3)
+#define	RX63N_PLLWTCR		(0x000800a6)
+#define	RX63N_DPSBYCR		(0x0008c280)
+#define	RX63N_DPSIER0		(0x0008c282)
+#define	RX63N_DPSIER1		(0x0008c283)
+#define	RX63N_DPSIER2		(0x0008c284)
+#define	RX63N_DPSIER3		(0x0008c285)
+#define	RX63N_DPSIFR0		(0x0008c286)
+#define	RX63N_DPSIFR1		(0x0008c287)
+#define	RX63N_DPSIFR2		(0x0008c288)
+#define	RX63N_DPSIFR3		(0x0008c289)
+#define	RX63N_DPSIEGR0		(0x0008c28a)
+#define	RX63N_DPSIEGR1		(0x0008c28b)
+#define	RX63N_DPSIEGR2		(0x0008c28c)
+#define	RX63N_DPSIEGR3		(0x0008c28d)
+
+/*
+ * 쥸饤ȥץƥǽ
+ */
 #define	RX63N_PRCR		(0x000803fe)
 
+/*
+ * ߥȥ(ICUb)
+ */
 #define	RX63N_IR10		(0x0008700a)
 #define	RX63N_IR11		(0x0008700b)
 #define	RX63N_IR12		(0x0008700c)
@@ -583,6 +620,263 @@
 #define	RX63N_IPR251		(0x000873fb)
 #define	RX63N_IPR252		(0x000873fc)
 #define	RX63N_IPR253		(0x000873fd)
+#define	RX63N_FIR		(0x000872f0)
+#define	RX63N_SWINTR		(0x000872e0)
+#define	RX63N_DTCER027		(0x0008711b)
+#define	RX63N_DTCER028		(0x0008711c)
+#define	RX63N_DTCER029		(0x0008711d)
+#define	RX63N_DTCER030		(0x0008711e)
+#define	RX63N_DTCER031		(0x0008711f)
+#define	RX63N_DTCER032		(0x00087120)
+#define	RX63N_DTCER033		(0x00087121)
+#define	RX63N_DTCER034		(0x00087122)
+#define	RX63N_DTCER035		(0x00087123)
+#define	RX63N_DTCER036		(0x00087124)
+#define	RX63N_DTCER037		(0x00087125)
+#define	RX63N_DTCER038		(0x00087126)
+#define	RX63N_DTCER039		(0x00087127)
+#define	RX63N_DTCER040		(0x00087128)
+#define	RX63N_DTCER041		(0x00087129)
+#define	RX63N_DTCER042		(0x0008712a)
+#define	RX63N_DTCER043		(0x0008712b)
+#define	RX63N_DTCER044		(0x0008712c)
+#define	RX63N_DTCER045		(0x0008712d)
+#define	RX63N_DTCER046		(0x0008712e)
+#define	RX63N_DTCER047		(0x0008712f)
+#define	RX63N_DTCER048		(0x00087130)
+#define	RX63N_DTCER049		(0x00087131)
+#define	RX63N_DTCER050		(0x00087132)
+#define	RX63N_DTCER051		(0x00087133)
+#define	RX63N_DTCER052		(0x00087134)
+#define	RX63N_DTCER053		(0x00087135)
+#define	RX63N_DTCER054		(0x00087136)
+#define	RX63N_DTCER055		(0x00087137)
+#define	RX63N_DTCER056		(0x00087138)
+#define	RX63N_DTCER057		(0x00087139)
+#define	RX63N_DTCER058		(0x0008713a)
+#define	RX63N_DTCER059		(0x0008713b)
+#define	RX63N_DTCER060		(0x0008713c)
+#define	RX63N_DTCER061		(0x0008713d)
+#define	RX63N_DTCER062		(0x0008713e)
+#define	RX63N_DTCER063		(0x0008713f)
+#define	RX63N_DTCER064		(0x00087140)
+#define	RX63N_DTCER065		(0x00087141)
+#define	RX63N_DTCER066		(0x00087142)
+#define	RX63N_DTCER067		(0x00087143)
+#define	RX63N_DTCER068		(0x00087144)
+#define	RX63N_DTCER069		(0x00087145)
+#define	RX63N_DTCER070		(0x00087146)
+#define	RX63N_DTCER071		(0x00087147)
+#define	RX63N_DTCER072		(0x00087148)
+#define	RX63N_DTCER073		(0x00087149)
+#define	RX63N_DTCER074		(0x0008714a)
+#define	RX63N_DTCER075		(0x0008714b)
+#define	RX63N_DTCER076		(0x0008714c)
+#define	RX63N_DTCER077		(0x0008714d)
+#define	RX63N_DTCER078		(0x0008714e)
+#define	RX63N_DTCER079		(0x0008714f)
+#define	RX63N_DTCER080		(0x00087150)
+#define	RX63N_DTCER081		(0x00087151)
+#define	RX63N_DTCER082		(0x00087152)
+#define	RX63N_DTCER083		(0x00087153)
+#define	RX63N_DTCER084		(0x00087154)
+#define	RX63N_DTCER085		(0x00087155)
+#define	RX63N_DTCER086		(0x00087156)
+#define	RX63N_DTCER087		(0x00087157)
+#define	RX63N_DTCER088		(0x00087158)
+#define	RX63N_DTCER089		(0x00087159)
+#define	RX63N_DTCER090		(0x0008715a)
+#define	RX63N_DTCER091		(0x0008715b)
+#define	RX63N_DTCER092		(0x0008715c)
+#define	RX63N_DTCER093		(0x0008715d)
+#define	RX63N_DTCER094		(0x0008715e)
+#define	RX63N_DTCER095		(0x0008715f)
+#define	RX63N_DTCER096		(0x00087160)
+#define	RX63N_DTCER097		(0x00087161)
+#define	RX63N_DTCER098		(0x00087162)
+#define	RX63N_DTCER099		(0x00087163)
+#define	RX63N_DTCER100		(0x00087164)
+#define	RX63N_DTCER101		(0x00087165)
+#define	RX63N_DTCER102		(0x00087166)
+#define	RX63N_DTCER103		(0x00087167)
+#define	RX63N_DTCER104		(0x00087168)
+#define	RX63N_DTCER105		(0x00087169)
+#define	RX63N_DTCER106		(0x0008716a)
+#define	RX63N_DTCER107		(0x0008716b)
+#define	RX63N_DTCER108		(0x0008716c)
+#define	RX63N_DTCER109		(0x0008716d)
+#define	RX63N_DTCER110		(0x0008716e)
+#define	RX63N_DTCER111		(0x0008716f)
+#define	RX63N_DTCER112		(0x00087170)
+#define	RX63N_DTCER113		(0x00087171)
+#define	RX63N_DTCER114		(0x00087172)
+#define	RX63N_DTCER115		(0x00087173)
+#define	RX63N_DTCER116		(0x00087174)
+#define	RX63N_DTCER117		(0x00087175)
+#define	RX63N_DTCER118		(0x00087176)
+#define	RX63N_DTCER119		(0x00087177)
+#define	RX63N_DTCER120		(0x00087178)
+#define	RX63N_DTCER121		(0x00087179)
+#define	RX63N_DTCER122		(0x0008717a)
+#define	RX63N_DTCER123		(0x0008717b)
+#define	RX63N_DTCER124		(0x0008717c)
+#define	RX63N_DTCER125		(0x0008717d)
+#define	RX63N_DTCER126		(0x0008717e)
+#define	RX63N_DTCER127		(0x0008717f)
+#define	RX63N_DTCER128		(0x00087180)
+#define	RX63N_DTCER129		(0x00087181)
+#define	RX63N_DTCER130		(0x00087182)
+#define	RX63N_DTCER131		(0x00087183)
+#define	RX63N_DTCER132		(0x00087184)
+#define	RX63N_DTCER133		(0x00087185)
+#define	RX63N_DTCER134		(0x00087186)
+#define	RX63N_DTCER135		(0x00087187)
+#define	RX63N_DTCER136		(0x00087188)
+#define	RX63N_DTCER137		(0x00087189)
+#define	RX63N_DTCER138		(0x0008718a)
+#define	RX63N_DTCER139		(0x0008718b)
+#define	RX63N_DTCER140		(0x0008718c)
+#define	RX63N_DTCER141		(0x0008718d)
+#define	RX63N_DTCER142		(0x0008718e)
+#define	RX63N_DTCER143		(0x0008718f)
+#define	RX63N_DTCER144		(0x00087190)
+#define	RX63N_DTCER145		(0x00087191)
+#define	RX63N_DTCER146		(0x00087192)
+#define	RX63N_DTCER147		(0x00087193)
+#define	RX63N_DTCER148		(0x00087194)
+#define	RX63N_DTCER149		(0x00087195)
+#define	RX63N_DTCER150		(0x00087196)
+#define	RX63N_DTCER151		(0x00087197)
+#define	RX63N_DTCER152		(0x00087198)
+#define	RX63N_DTCER153		(0x00087199)
+#define	RX63N_DTCER154		(0x0008719a)
+#define	RX63N_DTCER155		(0x0008719b)
+#define	RX63N_DTCER156		(0x0008719c)
+#define	RX63N_DTCER157		(0x0008719d)
+#define	RX63N_DTCER158		(0x0008719e)
+#define	RX63N_DTCER159		(0x0008719f)
+#define	RX63N_DTCER160		(0x000871a0)
+#define	RX63N_DTCER161		(0x000871a1)
+#define	RX63N_DTCER162		(0x000871a2)
+#define	RX63N_DTCER163		(0x000871a3)
+#define	RX63N_DTCER164		(0x000871a4)
+#define	RX63N_DTCER165		(0x000871a5)
+#define	RX63N_DTCER166		(0x000871a6)
+#define	RX63N_DTCER167		(0x000871a7)
+#define	RX63N_DTCER168		(0x000871a8)
+#define	RX63N_DTCER169		(0x000871a9)
+#define	RX63N_DTCER170		(0x000871aa)
+#define	RX63N_DTCER171		(0x000871ab)
+#define	RX63N_DTCER172		(0x000871ac)
+#define	RX63N_DTCER173		(0x000871ad)
+#define	RX63N_DTCER174		(0x000871ae)
+#define	RX63N_DTCER175		(0x000871af)
+#define	RX63N_DTCER176		(0x000871b0)
+#define	RX63N_DTCER177		(0x000871b1)
+#define	RX63N_DTCER178		(0x000871b2)
+#define	RX63N_DTCER179		(0x000871b3)
+#define	RX63N_DTCER180		(0x000871b4)
+#define	RX63N_DTCER181		(0x000871b5)
+#define	RX63N_DTCER182		(0x000871b6)
+#define	RX63N_DTCER183		(0x000871b7)
+#define	RX63N_DTCER184		(0x000871b8)
+#define	RX63N_DTCER185		(0x000871b9)
+#define	RX63N_DTCER186		(0x000871ba)
+#define	RX63N_DTCER187		(0x000871bb)
+#define	RX63N_DTCER188		(0x000871bc)
+#define	RX63N_DTCER189		(0x000871bd)
+#define	RX63N_DTCER190		(0x000871be)
+#define	RX63N_DTCER191		(0x000871bf)
+#define	RX63N_DTCER192		(0x000871c0)
+#define	RX63N_DTCER193		(0x000871c1)
+#define	RX63N_DTCER194		(0x000871c2)
+#define	RX63N_DTCER195		(0x000871c3)
+#define	RX63N_DTCER196		(0x000871c4)
+#define	RX63N_DTCER197		(0x000871c5)
+#define	RX63N_DTCER198		(0x000871c6)
+#define	RX63N_DTCER199		(0x000871c7)
+#define	RX63N_DTCER200		(0x000871c8)
+#define	RX63N_DTCER201		(0x000871c9)
+#define	RX63N_DTCER202		(0x000871ca)
+#define	RX63N_DTCER203		(0x000871cb)
+#define	RX63N_DTCER204		(0x000871cc)
+#define	RX63N_DTCER205		(0x000871cd)
+#define	RX63N_DTCER206		(0x000871ce)
+#define	RX63N_DTCER207		(0x000871cf)
+#define	RX63N_DTCER208		(0x000871d0)
+#define	RX63N_DTCER209		(0x000871d1)
+#define	RX63N_DTCER210		(0x000871d2)
+#define	RX63N_DTCER211		(0x000871d3)
+#define	RX63N_DTCER212		(0x000871d4)
+#define	RX63N_DTCER213		(0x000871d5)
+#define	RX63N_DTCER214		(0x000871d6)
+#define	RX63N_DTCER215		(0x000871d7)
+#define	RX63N_DTCER216		(0x000871d8)
+#define	RX63N_DTCER217		(0x000871d9)
+#define	RX63N_DTCER218		(0x000871da)
+#define	RX63N_DTCER219		(0x000871db)
+#define	RX63N_DTCER220		(0x000871dc)
+#define	RX63N_DTCER221		(0x000871dd)
+#define	RX63N_DTCER222		(0x000871de)
+#define	RX63N_DTCER223		(0x000871df)
+#define	RX63N_DTCER224		(0x000871e0)
+#define	RX63N_DTCER225		(0x000871e1)
+#define	RX63N_DTCER226		(0x000871e2)
+#define	RX63N_DTCER227		(0x000871e3)
+#define	RX63N_DTCER228		(0x000871e4)
+#define	RX63N_DTCER229		(0x000871e5)
+#define	RX63N_DTCER230		(0x000871e6)
+#define	RX63N_DTCER231		(0x000871e7)
+#define	RX63N_DTCER232		(0x000871e8)
+#define	RX63N_DTCER233		(0x000871e9)
+#define	RX63N_DTCER234		(0x000871ea)
+#define	RX63N_DTCER235		(0x000871eb)
+#define	RX63N_DTCER236		(0x000871ec)
+#define	RX63N_DTCER237		(0x000871ed)
+#define	RX63N_DTCER238		(0x000871ee)
+#define	RX63N_DTCER239		(0x000871ef)
+#define	RX63N_DTCER240		(0x000871f0)
+#define	RX63N_DTCER241		(0x000871f1)
+#define	RX63N_DTCER242		(0x000871f2)
+#define	RX63N_DTCER243		(0x000871f3)
+#define	RX63N_DTCER244		(0x000871f4)
+#define	RX63N_DTCER245		(0x000871f5)
+#define	RX63N_DTCER246		(0x000871f6)
+#define	RX63N_DTCER247		(0x000871f7)
+#define	RX63N_DTCER248		(0x000871f8)
+#define	RX63N_DTCER249		(0x000871f9)
+#define	RX63N_DTCER250		(0x000871fa)
+#define	RX63N_DTCER251		(0x000871fb)
+#define	RX63N_DMRSR0		(0x00087400)
+#define	RX63N_DMRSR1		(0x00087404)
+#define	RX63N_DMRSR2		(0x00087408)
+#define	RX63N_DMRSR3		(0x0008740c)
+#define	RX63N_IRQCR0		(0x00087500)
+#define	RX63N_IRQCR1		(0x00087501)
+#define	RX63N_IRQCR2		(0x00087502)
+#define	RX63N_IRQCR3		(0x00087503)
+#define	RX63N_IRQCR4		(0x00087504)
+#define	RX63N_IRQCR5		(0x00087505)
+#define	RX63N_IRQCR6		(0x00087506)
+#define	RX63N_IRQCR7		(0x00087507)
+#define	RX63N_IRQCR8		(0x00087508)
+#define	RX63N_IRQCR9		(0x00087509)
+#define	RX63N_IRQCR10		(0x0008750a)
+#define	RX63N_IRQCR11		(0x0008750b)
+#define	RX63N_IRQCR12		(0x0008750c)
+#define	RX63N_IRQCR13		(0x0008750d)
+#define	RX63N_IRQCR14		(0x0008750e)
+#define	RX63N_IRQCR15		(0x0008750f)
+#define	RX63N_IRQFLTE0		(0x00087510)
+#define	RX63N_IRQFLTE1		(0x00087511)
+#define	RX63N_IRQFLTC0		(0x00087514)
+#define	RX63N_IRQFLTC1		(0x00087516)
+#define	RX63N_NMISR		(0x00087580)
+#define	RX63N_NMIER		(0x00087581)
+#define	RX63N_NMICLR		(0x00087582)
+#define	RX63N_NMICR		(0x00087583)
+#define	RX63N_NMIFLTE		(0x00087590)
+#define	RX63N_NMIFLTC		(0x00087594)
 #define	RX63N_GRP00		(0x0008c300)
 #define	RX63N_GRP01		(0x0008c304)
 #define	RX63N_GRP02		(0x0008c308)
@@ -599,7 +893,209 @@
 #define	RX63N_GEN05		(0x0008c354)
 #define	RX63N_GEN06		(0x0008c358)
 #define	RX63N_GEN12		(0x0008c370)
+#define	RX63N_GCR00		(0x0008c380)
+#define	RX63N_GCR01		(0x0008c384)
+#define	RX63N_GCR02		(0x0008c388)
+#define	RX63N_GCR03		(0x0008c38c)
+#define	RX63N_GCR04		(0x0008c390)
+#define	RX63N_GCR05		(0x0008c394)
+#define	RX63N_GCR06		(0x0008c398)
+#define	RX63N_SEL		(0x0008c3c0)
 
+/*
+ * I/O ݡ
+ */
+#define	RX63N_PORT0_PDR		(0x0008c000)
+#define	RX63N_PORT1_PDR		(0x0008c001)
+#define	RX63N_PORT2_PDR		(0x0008c002)
+#define	RX63N_PORT3_PDR		(0x0008c003)
+#define	RX63N_PORT4_PDR		(0x0008c004)
+#define	RX63N_PORT5_PDR		(0x0008c005)
+#define	RX63N_PORT6_PDR		(0x0008c006)
+#define	RX63N_PORT7_PDR		(0x0008c007)
+#define	RX63N_PORT8_PDR		(0x0008c008)
+#define	RX63N_PORT9_PDR		(0x0008c009)
+#define	RX63N_PORTA_PDR		(0x0008c00a)
+#define	RX63N_PORTB_PDR		(0x0008c00b)
+#define	RX63N_PORTC_PDR		(0x0008c00c)
+#define	RX63N_PORTD_PDR		(0x0008c00d)
+#define	RX63N_PORTE_PDR		(0x0008c00e)
+#define	RX63N_PORTF_PDR		(0x0008c00f)
+#define	RX63N_PORTG_PDR		(0x0008c010)
+#define	RX63N_PORTJ_PDR		(0x0008c012)
+#define	RX63N_PORT0_PODR	(0x0008c020)
+#define	RX63N_PORT1_PODR	(0x0008c021)
+#define	RX63N_PORT2_PODR	(0x0008c022)
+#define	RX63N_PORT3_PODR	(0x0008c023)
+#define	RX63N_PORT4_PODR	(0x0008c024)
+#define	RX63N_PORT5_PODR	(0x0008c025)
+#define	RX63N_PORT6_PODR	(0x0008c026)
+#define	RX63N_PORT7_PODR	(0x0008c027)
+#define	RX63N_PORT8_PODR	(0x0008c028)
+#define	RX63N_PORT9_PODR	(0x0008c029)
+#define	RX63N_PORTA_PODR	(0x0008c02a)
+#define	RX63N_PORTB_PODR	(0x0008c02b)
+#define	RX63N_PORTC_PODR	(0x0008c02c)
+#define	RX63N_PORTD_PODR	(0x0008c02d)
+#define	RX63N_PORTE_PODR	(0x0008c02e)
+#define	RX63N_PORTF_PODR	(0x0008c02f)
+#define	RX63N_PORTG_PODR	(0x0008c030)
+#define	RX63N_PORTJ_PODR	(0x0008c032)
+#define	RX63N_PORT0_PIDR	(0x0008c040)
+#define	RX63N_PORT1_PIDR	(0x0008c041)
+#define	RX63N_PORT2_PIDR	(0x0008c042)
+#define	RX63N_PORT3_PIDR	(0x0008c043)
+#define	RX63N_PORT4_PIDR	(0x0008c044)
+#define	RX63N_PORT5_PIDR	(0x0008c045)
+#define	RX63N_PORT6_PIDR	(0x0008c046)
+#define	RX63N_PORT7_PIDR	(0x0008c047)
+#define	RX63N_PORT8_PIDR	(0x0008c048)
+#define	RX63N_PORT9_PIDR	(0x0008c049)
+#define	RX63N_PORTA_PIDR	(0x0008c04a)
+#define	RX63N_PORTB_PIDR	(0x0008c04b)
+#define	RX63N_PORTC_PIDR	(0x0008c04c)
+#define	RX63N_PORTD_PIDR	(0x0008c04d)
+#define	RX63N_PORTE_PIDR	(0x0008c04e)
+#define	RX63N_PORTF_PIDR	(0x0008c04f)
+#define	RX63N_PORTG_PIDR	(0x0008c050)
+#define	RX63N_PORTJ_PIDR	(0x0008c052)
+#define	RX63N_PORT0_PMR		(0x0008c060)
+#define	RX63N_PORT1_PMR		(0x0008c061)
+#define	RX63N_PORT2_PMR		(0x0008c062)
+#define	RX63N_PORT3_PMR		(0x0008c063)
+#define	RX63N_PORT4_PMR		(0x0008c064)
+#define	RX63N_PORT5_PMR		(0x0008c065)
+#define	RX63N_PORT6_PMR		(0x0008c066)
+#define	RX63N_PORT7_PMR		(0x0008c067)
+#define	RX63N_PORT8_PMR		(0x0008c068)
+#define	RX63N_PORT9_PMR		(0x0008c069)
+#define	RX63N_PORTA_PMR		(0x0008c06a)
+#define	RX63N_PORTB_PMR		(0x0008c06b)
+#define	RX63N_PORTC_PMR		(0x0008c06c)
+#define	RX63N_PORTD_PMR		(0x0008c06d)
+#define	RX63N_PORTE_PMR		(0x0008c06e)
+#define	RX63N_PORTF_PMR		(0x0008c06f)
+#define	RX63N_PORTG_PMR		(0x0008c070)
+#define	RX63N_PORTJ_PMR		(0x0008c072)
+
+
+/*
+ * ޥե󥯥ԥ󥳥ȥ(MPC)
+ */
+#define	RX63N_PWPR		(0x0008c11f)
+#define	RX63N_P00PFS		(0x0008c140)
+#define	RX63N_P01PFS		(0x0008c141)
+#define	RX63N_P02PFS		(0x0008c142)
+#define	RX63N_P03PFS		(0x0008c143)
+#define	RX63N_P05PFS		(0x0008c145)
+#define	RX63N_P07PFS		(0x0008c147)
+#define	RX63N_P10PFS		(0x0008c148)
+#define	RX63N_P11PFS		(0x0008c149)
+#define	RX63N_P12PFS		(0x0008c14a)
+#define	RX63N_P13PFS		(0x0008c14b)
+#define	RX63N_P14PFS		(0x0008c14c)
+#define	RX63N_P15PFS		(0x0008c14d)
+#define	RX63N_P16PFS		(0x0008c14e)
+#define	RX63N_P17PFS		(0x0008c14f)
+#define	RX63N_P20PFS		(0x0008c150)
+#define	RX63N_P21PFS		(0x0008c151)
+#define	RX63N_P22PFS		(0x0008c152)
+#define	RX63N_P23PFS		(0x0008c153)
+#define	RX63N_P24PFS		(0x0008c154)
+#define	RX63N_P25PFS		(0x0008c155)
+#define	RX63N_P26PFS		(0x0008c156)
+#define	RX63N_P27PFS		(0x0008c157)
+#define	RX63N_P30PFS		(0x0008c158)
+#define	RX63N_P31PFS		(0x0008c159)
+#define	RX63N_P32PFS		(0x0008c15a)
+#define	RX63N_P33PFS		(0x0008c15b)
+#define	RX63N_P34PFS		(0x0008c15c)
+#define	RX63N_P40PFS		(0x0008c160)
+#define	RX63N_P41PFS		(0x0008c161)
+#define	RX63N_P42PFS		(0x0008c162)
+#define	RX63N_P43PFS		(0x0008c163)
+#define	RX63N_P44PFS		(0x0008c164)
+#define	RX63N_P45PFS		(0x0008c165)
+#define	RX63N_P46PFS		(0x0008c166)
+#define	RX63N_P47PFS		(0x0008c167)
+#define	RX63N_P50PFS		(0x0008c168)
+#define	RX63N_P51PFS		(0x0008c169)
+#define	RX63N_P52PFS		(0x0008c16a)
+#define	RX63N_P54PFS		(0x0008c16c)
+#define	RX63N_P55PFS		(0x0008c16d)
+#define	RX63N_P56PFS		(0x0008c16e)
+#define	RX63N_P57PFS		(0x0008c16f)
+#define	RX63N_P60PFS		(0x0008c170)
+#define	RX63N_P61PFS		(0x0008c171)
+#define	RX63N_P66PFS		(0x0008c176)
+#define	RX63N_P67PFS		(0x0008c177)
+#define	RX63N_P70PFS		(0x0008c178)
+#define	RX63N_P71PFS		(0x0008c179)
+#define	RX63N_P72PFS		(0x0008c17a)
+#define	RX63N_P73PFS		(0x0008c17b)
+#define	RX63N_P74PFS		(0x0008c17c)
+#define	RX63N_P75PFS		(0x0008c17d)
+#define	RX63N_P76PFS		(0x0008c17e)
+#define	RX63N_P77PFS		(0x0008c17f)
+#define	RX63N_P80PFS		(0x0008c180)
+#define	RX63N_P81PFS		(0x0008c181)
+#define	RX63N_P82PFS		(0x0008c182)
+#define	RX63N_P83PFS		(0x0008c183)
+#define	RX63N_P86PFS		(0x0008c186)
+#define	RX63N_P87PFS		(0x0008c187)
+#define	RX63N_P90PFS		(0x0008c188)
+#define	RX63N_P91PFS		(0x0008c189)
+#define	RX63N_P92PFS		(0x0008c18a)
+#define	RX63N_P93PFS		(0x0008c18b)
+#define	RX63N_PA0PFS		(0x0008c190)
+#define	RX63N_PA1PFS		(0x0008c191)
+#define	RX63N_PA2PFS		(0x0008c192)
+#define	RX63N_PA3PFS		(0x0008c193)
+#define	RX63N_PA4PFS		(0x0008c194)
+#define	RX63N_PA5PFS		(0x0008c195)
+#define	RX63N_PA6PFS		(0x0008c196)
+#define	RX63N_PA7PFS		(0x0008c197)
+#define	RX63N_PB0PFS		(0x0008c198)
+#define	RX63N_PB1PFS		(0x0008c199)
+#define	RX63N_PB2PFS		(0x0008c19a)
+#define	RX63N_PB3PFS		(0x0008c19b)
+#define	RX63N_PB4PFS		(0x0008c19c)
+#define	RX63N_PB5PFS		(0x0008c19d)
+#define	RX63N_PB6PFS		(0x0008c19e)
+#define	RX63N_PB7PFS		(0x0008c19f)
+#define	RX63N_PC0PFS		(0x0008c1a0)
+#define	RX63N_PC1PFS		(0x0008c1a1)
+#define	RX63N_PC2PFS		(0x0008c1a2)
+#define	RX63N_PC3PFS		(0x0008c1a3)
+#define	RX63N_PC4PFS		(0x0008c1a4)
+#define	RX63N_PC5PFS		(0x0008c1a5)
+#define	RX63N_PC6PFS		(0x0008c1a6)
+#define	RX63N_PC7PFS		(0x0008c1a7)
+#define	RX63N_PD0PFS		(0x0008c1a8)
+#define	RX63N_PD1PFS		(0x0008c1a9)
+#define	RX63N_PD2PFS		(0x0008c1aa)
+#define	RX63N_PD3PFS		(0x0008c1ab)
+#define	RX63N_PD4PFS		(0x0008c1ac)
+#define	RX63N_PD5PFS		(0x0008c1ad)
+#define	RX63N_PD6PFS		(0x0008c1ae)
+#define	RX63N_PD7PFS		(0x0008c1af)
+#define	RX63N_PE0PFS		(0x0008c1b0)
+#define	RX63N_PE1PFS		(0x0008c1b1)
+#define	RX63N_PE2PFS		(0x0008c1b2)
+#define	RX63N_PE3PFS		(0x0008c1b3)
+#define	RX63N_PE4PFS		(0x0008c1b4)
+#define	RX63N_PE5PFS		(0x0008c1b5)
+#define	RX63N_PE6PFS		(0x0008c1b6)
+#define	RX63N_PE7PFS		(0x0008c1b7)
+#define	RX63N_PF0PFS		(0x0008c1b8)
+#define	RX63N_PF1PFS		(0x0008c1b9)
+#define	RX63N_PF2PFS		(0x0008c1ba)
+#define	RX63N_PF5PFS		(0x0008c1bd)
+#define	RX63N_PJ3PFS		(0x0008c1d3)
+
+/*
+ * ڥޥå(CMT)
+ */
 #define	RX63N_CMSTR0		(0x00088000)
 #define	RX63N_CMT0_CMCR		(0x00088002)
 #define	RX63N_CMT0_CMCNT	(0x00088004)
@@ -615,6 +1111,9 @@
 #define	RX63N_CMT3_CMCNT	(0x0008801a)
 #define	RX63N_CMT3_CMCOR	(0x0008801c)
 
+/*
+ * ꥢ륳ߥ˥󥤥󥿥ե(SCIcSCId)
+ */
 #define	RX63N_SCI0_SMR		(0x0008a000)
 #define	RX63N_SCI0_BRR		(0x0008a001)
 #define	RX63N_SCI0_SCR		(0x0008a002)
@@ -752,172 +1251,4 @@
 #define	RX63N_SCI12_SIMR1	(0x0008a189)
 #define	RX63N_SCI12_SPMR	(0x0008a18d)
 
-#define	RX63N_PORT0_PMR		(0x0008c060)
-#define	RX63N_PORT1_PMR		(0x0008c061)
-#define	RX63N_PORT2_PMR		(0x0008c062)
-#define	RX63N_PORT3_PMR		(0x0008c063)
-#define	RX63N_PORT4_PMR		(0x0008c064)
-#define	RX63N_PORT5_PMR		(0x0008c065)
-#define	RX63N_PORT6_PMR		(0x0008c066)
-#define	RX63N_PORT7_PMR		(0x0008c067)
-#define	RX63N_PORT8_PMR		(0x0008c068)
-#define	RX63N_PORT9_PMR		(0x0008c069)
-#define	RX63N_PORTA_PMR		(0x0008c06a)
-#define	RX63N_PORTB_PMR		(0x0008c06b)
-#define	RX63N_PORTC_PMR		(0x0008c06c)
-#define	RX63N_PORTD_PMR		(0x0008c06d)
-#define	RX63N_PORTE_PMR		(0x0008c06e)
-#define	RX63N_PORTF_PMR		(0x0008c06f)
-#define	RX63N_PORTG_PMR		(0x0008c070)
-#define	RX63N_PORTJ_PMR		(0x0008c072)
-#define	RX63N_PWPR		(0x0008c11f)
-
-#define	RX63N_PORT0_PDR		(0x0008c000)
-#define	RX63N_PORT1_PDR		(0x0008c001)
-#define	RX63N_PORT2_PDR		(0x0008c002)
-#define	RX63N_PORT3_PDR		(0x0008c003)
-#define	RX63N_PORT4_PDR		(0x0008c004)
-#define	RX63N_PORT5_PDR		(0x0008c005)
-#define	RX63N_PORT6_PDR		(0x0008c006)
-#define	RX63N_PORT7_PDR		(0x0008c007)
-#define	RX63N_PORT8_PDR		(0x0008c008)
-#define	RX63N_PORT9_PDR		(0x0008c009)
-#define	RX63N_PORTA_PDR		(0x0008c00a)
-#define	RX63N_PORTB_PDR		(0x0008c00b)
-#define	RX63N_PORTC_PDR		(0x0008c00c)
-#define	RX63N_PORTD_PDR		(0x0008c00d)
-#define	RX63N_PORTE_PDR		(0x0008c00e)
-#define	RX63N_PORTF_PDR		(0x0008c00f)
-#define	RX63N_PORTG_PDR		(0x0008c010)
-#define	RX63N_PORTJ_PDR		(0x0008c012)
-
-#define	RX63N_PORT0_PODR	(0x0008c020)
-#define	RX63N_PORT1_PODR	(0x0008c021)
-#define	RX63N_PORT2_PODR	(0x0008c022)
-#define	RX63N_PORT3_PODR	(0x0008c023)
-#define	RX63N_PORT4_PODR	(0x0008c024)
-#define	RX63N_PORT5_PODR	(0x0008c025)
-#define	RX63N_PORT6_PODR	(0x0008c026)
-#define	RX63N_PORT7_PODR	(0x0008c027)
-#define	RX63N_PORT8_PODR	(0x0008c028)
-#define	RX63N_PORT9_PODR	(0x0008c029)
-#define	RX63N_PORTA_PODR	(0x0008c02a)
-#define	RX63N_PORTB_PODR	(0x0008c02b)
-#define	RX63N_PORTC_PODR	(0x0008c02c)
-#define	RX63N_PORTD_PODR	(0x0008c02d)
-#define	RX63N_PORTE_PODR	(0x0008c02e)
-#define	RX63N_PORTF_PODR	(0x0008c02f)
-#define	RX63N_PORTG_PODR	(0x0008c030)
-#define	RX63N_PORTJ_PODR	(0x0008c032)
-
-#define	RX63N_P00PFS		(0x0008c140)
-#define	RX63N_P01PFS		(0x0008c141)
-#define	RX63N_P02PFS		(0x0008c142)
-#define	RX63N_P03PFS		(0x0008c143)
-#define	RX63N_P05PFS		(0x0008c145)
-#define	RX63N_P07PFS		(0x0008c147)
-#define	RX63N_P10PFS		(0x0008c148)
-#define	RX63N_P11PFS		(0x0008c149)
-#define	RX63N_P12PFS		(0x0008c14a)
-#define	RX63N_P13PFS		(0x0008c14b)
-#define	RX63N_P14PFS		(0x0008c14c)
-#define	RX63N_P15PFS		(0x0008c14d)
-#define	RX63N_P16PFS		(0x0008c14e)
-#define	RX63N_P17PFS		(0x0008c14f)
-#define	RX63N_P20PFS		(0x0008c150)
-#define	RX63N_P21PFS		(0x0008c151)
-#define	RX63N_P22PFS		(0x0008c152)
-#define	RX63N_P23PFS		(0x0008c153)
-#define	RX63N_P24PFS		(0x0008c154)
-#define	RX63N_P25PFS		(0x0008c155)
-#define	RX63N_P26PFS		(0x0008c156)
-#define	RX63N_P27PFS		(0x0008c157)
-#define	RX63N_P30PFS		(0x0008c158)
-#define	RX63N_P31PFS		(0x0008c159)
-#define	RX63N_P32PFS		(0x0008c15a)
-#define	RX63N_P33PFS		(0x0008c15b)
-#define	RX63N_P34PFS		(0x0008c15c)
-#define	RX63N_P40PFS		(0x0008c160)
-#define	RX63N_P41PFS		(0x0008c161)
-#define	RX63N_P42PFS		(0x0008c162)
-#define	RX63N_P43PFS		(0x0008c163)
-#define	RX63N_P44PFS		(0x0008c164)
-#define	RX63N_P45PFS		(0x0008c165)
-#define	RX63N_P46PFS		(0x0008c166)
-#define	RX63N_P47PFS		(0x0008c167)
-#define	RX63N_P50PFS		(0x0008c168)
-#define	RX63N_P51PFS		(0x0008c169)
-#define	RX63N_P52PFS		(0x0008c16a)
-#define	RX63N_P54PFS		(0x0008c16c)
-#define	RX63N_P55PFS		(0x0008c16d)
-#define	RX63N_P56PFS		(0x0008c16e)
-#define	RX63N_P57PFS		(0x0008c16f)
-#define	RX63N_P60PFS		(0x0008c170)
-#define	RX63N_P61PFS		(0x0008c171)
-#define	RX63N_P66PFS		(0x0008c176)
-#define	RX63N_P67PFS		(0x0008c177)
-#define	RX63N_P70PFS		(0x0008c178)
-#define	RX63N_P71PFS		(0x0008c179)
-#define	RX63N_P72PFS		(0x0008c17a)
-#define	RX63N_P73PFS		(0x0008c17b)
-#define	RX63N_P74PFS		(0x0008c17c)
-#define	RX63N_P75PFS		(0x0008c17d)
-#define	RX63N_P76PFS		(0x0008c17e)
-#define	RX63N_P77PFS		(0x0008c17f)
-#define	RX63N_P80PFS		(0x0008c180)
-#define	RX63N_P81PFS		(0x0008c181)
-#define	RX63N_P82PFS		(0x0008c182)
-#define	RX63N_P83PFS		(0x0008c183)
-#define	RX63N_P86PFS		(0x0008c186)
-#define	RX63N_P87PFS		(0x0008c187)
-#define	RX63N_P90PFS		(0x0008c188)
-#define	RX63N_P91PFS		(0x0008c189)
-#define	RX63N_P92PFS		(0x0008c18a)
-#define	RX63N_P93PFS		(0x0008c18b)
-#define	RX63N_PA0PFS		(0x0008c190)
-#define	RX63N_PA1PFS		(0x0008c191)
-#define	RX63N_PA2PFS		(0x0008c192)
-#define	RX63N_PA3PFS		(0x0008c193)
-#define	RX63N_PA4PFS		(0x0008c194)
-#define	RX63N_PA5PFS		(0x0008c195)
-#define	RX63N_PA6PFS		(0x0008c196)
-#define	RX63N_PA7PFS		(0x0008c197)
-#define	RX63N_PB0PFS		(0x0008c198)
-#define	RX63N_PB1PFS		(0x0008c199)
-#define	RX63N_PB2PFS		(0x0008c19a)
-#define	RX63N_PB3PFS		(0x0008c19b)
-#define	RX63N_PB4PFS		(0x0008c19c)
-#define	RX63N_PB5PFS		(0x0008c19d)
-#define	RX63N_PB6PFS		(0x0008c19e)
-#define	RX63N_PB7PFS		(0x0008c19f)
-#define	RX63N_PC0PFS		(0x0008c1a0)
-#define	RX63N_PC1PFS		(0x0008c1a1)
-#define	RX63N_PC2PFS		(0x0008c1a2)
-#define	RX63N_PC3PFS		(0x0008c1a3)
-#define	RX63N_PC4PFS		(0x0008c1a4)
-#define	RX63N_PC5PFS		(0x0008c1a5)
-#define	RX63N_PC6PFS		(0x0008c1a6)
-#define	RX63N_PC7PFS		(0x0008c1a7)
-#define	RX63N_PD0PFS		(0x0008c1a8)
-#define	RX63N_PD1PFS		(0x0008c1a9)
-#define	RX63N_PD2PFS		(0x0008c1aa)
-#define	RX63N_PD3PFS		(0x0008c1ab)
-#define	RX63N_PD4PFS		(0x0008c1ac)
-#define	RX63N_PD5PFS		(0x0008c1ad)
-#define	RX63N_PD6PFS		(0x0008c1ae)
-#define	RX63N_PD7PFS		(0x0008c1af)
-#define	RX63N_PE0PFS		(0x0008c1b0)
-#define	RX63N_PE1PFS		(0x0008c1b1)
-#define	RX63N_PE2PFS		(0x0008c1b2)
-#define	RX63N_PE3PFS		(0x0008c1b3)
-#define	RX63N_PE4PFS		(0x0008c1b4)
-#define	RX63N_PE5PFS		(0x0008c1b5)
-#define	RX63N_PE6PFS		(0x0008c1b6)
-#define	RX63N_PE7PFS		(0x0008c1b7)
-#define	RX63N_PF0PFS		(0x0008c1b8)
-#define	RX63N_PF1PFS		(0x0008c1b9)
-#define	RX63N_PF2PFS		(0x0008c1ba)
-#define	RX63N_PF5PFS		(0x0008c1bd)
-#define	RX63N_PJ3PFS		(0x0008c1d3)
-
 #endif	/* _RX63N_H_ */
